@@ -16,7 +16,7 @@ from joblib import dump, load
 from sklearn.cluster import dbscan
 import tempfile
 
-logger = logging.getLogger('Top2Vec')
+logger = logging.getLogger('top2vec')
 logger.setLevel(logging.WARNING)
 sh = logging.StreamHandler()
 sh.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
@@ -30,7 +30,7 @@ def default_tokenizer(doc):
 
 class Top2Vec:
     """
-    Topic2Vector
+    Top2Vec
 
     Creates jointly embedded topic, document and word vectors.
 
@@ -40,13 +40,18 @@ class Top2Vec:
     documents: List of str
         Input corpus, should be a list of strings.
 
-    speed: string (Optional, default 'fast-learn')
+    min_count: int (Optional, default 50)
+        Ignores all words with total frequency lower than this. For smaller
+        corpora a smaller min_count will be necessary.
+
+    speed: string (Optional, default 'learn')
         This parameter will determine how fast the model takes to train. The
         fast-learn option is the fastest and will generate the lowest quality
         vectors. The learn option will learn better quality vectors but take
         a longer time to train. The deep-learn option will learn the best quality
         vectors but will take significant time to train. The valid string speed
         options are:
+        
             * fast-learn
             * learn
             * deep-learn
@@ -59,8 +64,8 @@ class Top2Vec:
 
     document_ids: List of str, int (Optional)
         A unique value per document that will be used for referring to documents
-        in search results. If ids are not given, the index of each document
-        in the original corpus will become the id.
+        in search results. If ids are not given to the model, the index of each
+        document in the original corpus will become the id.
 
     keep_documents: bool (Optional, default True)
         If set to False documents will only be used for training and not saved
@@ -71,7 +76,7 @@ class Top2Vec:
         The amount of worker threads to be used in training the model. Larger
         amount will lead to faster training.
     
-    tokenizer: callable or None (default)
+    tokenizer: callable (Optional, default None)
         Override the default tokenization method. If None then gensim.utils.simple_preprocess
         will be used.
     
@@ -80,8 +85,8 @@ class Top2Vec:
 
     """
 
-    def __init__(self, documents, speed="fast-learn", use_corpus_file=False, document_ids=None, keep_documents=True,
-                 workers=None, tokenizer=None, verbose=False):
+    def __init__(self, documents, min_count=50, speed="learn", use_corpus_file=False, document_ids=None,
+                 keep_documents=True, workers=None, tokenizer=None, verbose=False):
 
         if verbose:
             logger.setLevel(logging.DEBUG)
@@ -130,7 +135,6 @@ class Top2Vec:
 
         # validate document ids
         if document_ids is not None:
-
             if len(documents) != len(document_ids):
                 raise ValueError("Document ids need to match number of documents")
             elif len(document_ids) != len(set(document_ids)):
@@ -150,23 +154,19 @@ class Top2Vec:
             self.doc_id2index = None
             self.doc_id_type = np.int_
 
-        logger.info('Pre-processing documents for training')
         if use_corpus_file:
-            processed = [self._tokenizer(doc) for doc in documents]
-            lines = [' '.join(line) + "\n" for line in processed]
+            logger.info('Pre-processing documents for training')
+            processed = [' '.join(self._tokenizer(doc)) for doc in documents]
+            lines = "\n".join(processed)
             temp = tempfile.NamedTemporaryFile(mode='w+t')
-            temp.writelines(lines)
-        else:
-            train_corpus = [TaggedDocument(self._tokenizer(doc), [i])
-                            for i, doc in enumerate(documents)]
+            temp.write(lines)
 
-        # create documents and word embeddings with doc2vec
-        logger.info('Creating joint document/word embedding')
-        if use_corpus_file:
+            logger.info('Creating joint document/word embedding')
             if workers is None:
                 self.model = Doc2Vec(corpus_file=temp.name,
                                      vector_size=300,
-                                     min_count=50, window=15,
+                                     min_count=min_count,
+                                     window=15,
                                      sample=1e-5,
                                      negative=negative,
                                      hs=hs,
@@ -176,7 +176,7 @@ class Top2Vec:
             else:
                 self.model = Doc2Vec(corpus_file=temp.name,
                                      vector_size=300,
-                                     min_count=50,
+                                     min_count=min_count,
                                      window=15,
                                      sample=1e-5,
                                      negative=negative,
@@ -188,10 +188,16 @@ class Top2Vec:
 
             temp.close()
         else:
+            logger.info('Pre-processing documents for training')
+            train_corpus = [TaggedDocument(self._tokenizer(doc), [i])
+                            for i, doc in enumerate(documents)]
+
+            logger.info('Creating joint document/word embedding')
             if workers is None:
                 self.model = Doc2Vec(documents=train_corpus,
                                      vector_size=300,
-                                     min_count=50, window=15,
+                                     min_count=min_count,
+                                     window=15,
                                      sample=1e-5,
                                      negative=negative,
                                      hs=hs,
@@ -201,7 +207,7 @@ class Top2Vec:
             else:
                 self.model = Doc2Vec(documents=train_corpus,
                                      vector_size=300,
-                                     min_count=50,
+                                     min_count=min_count,
                                      window=15,
                                      sample=1e-5,
                                      negative=negative,
@@ -225,17 +231,25 @@ class Top2Vec:
 
         # calculate topic vectors from dense areas of documents
         logger.info('Finding topics')
+
+        # create topic vectors
         self._create_topic_vectors(cluster.labels_)
 
         # deduplicate topics
         self._deduplicate_topics()
 
-        # calculate topic sizes and index nearest topic for each document
-        self.topic_vectors, self.doc_top, self.doc_dist, self.topic_sizes = self._calculate_topic_sizes(
-            self.topic_vectors)
-
         # find topic words and scores
-        self.topic_words, self.topic_word_scores = self._find_topic_words_scores(topic_vectors=self.topic_vectors)
+        self.topic_words, self.topic_word_scores = self._find_topic_words_and_scores(topic_vectors=self.topic_vectors)
+
+        # assign documents to topic
+        self.doc_top, self.doc_dist = self._calculate_documents_topic(self.topic_vectors,
+                                                                      self.model.docvecs.vectors_docs)
+
+        # calculate topic sizes
+        self.topic_sizes = self._calculate_topic_sizes(hierarchy=False)
+
+        # re-order topics
+        self._reorder_topics(hierarchy=False)
 
         # initialize variables for hierarchical topic reduction
         self.topic_vectors_reduced = None
@@ -278,28 +292,31 @@ class Top2Vec:
 
             self.topic_vectors = unique_topics
 
-    def _calculate_topic_sizes(self, topic_vectors, hierarchy=None):
-        # find nearest topic of each document
-        doc_top, doc_dist = self._calculate_documents_topic(topic_vectors=topic_vectors,
-                                                            document_vectors=self.model.docvecs.vectors_docs)
-        topic_sizes = pd.Series(doc_top).value_counts()
-
-        return self._reorder_topics(topic_vectors, topic_sizes, doc_top, doc_dist, hierarchy)
-
-    @staticmethod
-    def _reorder_topics(topic_vectors, topic_sizes, doc_top, doc_dist, hierarchy=None):
-        topic_vectors = topic_vectors[topic_sizes.index]
-        old2new = dict(zip(topic_sizes.index, range(topic_sizes.shape[0])))
-        doc_top = np.array([old2new[i] for i in doc_top])
-
-        if hierarchy is None:
-            topic_sizes.reset_index(drop=True, inplace=True)
-            return topic_vectors, doc_top, doc_dist, topic_sizes
-
+    def _calculate_topic_sizes(self, hierarchy=False):
+        if hierarchy:
+            topic_sizes = pd.Series(self.doc_top_reduced).value_counts()
         else:
-            hierarchy = [hierarchy[i] for i in topic_sizes.index]
-            topic_sizes.reset_index(drop=True, inplace=True)
-            return topic_vectors, doc_top, doc_dist, topic_sizes, hierarchy
+            topic_sizes = pd.Series(self.doc_top).value_counts()
+
+        return topic_sizes
+
+    def _reorder_topics(self, hierarchy=False):
+
+        if hierarchy:
+            self.topic_vectors_reduced = self.topic_vectors_reduced[self.topic_sizes_reduced.index]
+            self.topic_words_reduced = self.topic_words_reduced[self.topic_sizes_reduced.index]
+            self.topic_word_scores_reduced = self.topic_word_scores_reduced[self.topic_sizes_reduced.index]
+            old2new = dict(zip(self.topic_sizes_reduced.index, range(self.topic_sizes_reduced.index.shape[0])))
+            self.doc_top_reduced = np.array([old2new[i] for i in self.doc_top_reduced])
+            self.hierarchy = [self.hierarchy[i] for i in self.topic_sizes_reduced.index]
+            self.topic_sizes_reduced.reset_index(drop=True, inplace=True)
+        else:
+            self.topic_vectors = self.topic_vectors[self.topic_sizes.index]
+            self.topic_words = self.topic_words[self.topic_sizes.index]
+            self.topic_word_scores = self.topic_word_scores[self.topic_sizes.index]
+            old2new = dict(zip(self.topic_sizes.index, range(self.topic_sizes.index.shape[0])))
+            self.doc_top = np.array([old2new[i] for i in self.doc_top])
+            self.topic_sizes.reset_index(drop=True, inplace=True)
 
     @staticmethod
     def _calculate_documents_topic(topic_vectors, document_vectors, dist=True):
@@ -338,7 +355,7 @@ class Top2Vec:
         else:
             return doc_top
 
-    def _find_topic_words_scores(self, topic_vectors):
+    def _find_topic_words_and_scores(self, topic_vectors):
         topic_words = []
         topic_word_scores = []
 
@@ -352,6 +369,51 @@ class Top2Vec:
 
         return topic_words, topic_word_scores
 
+    def _assign_documents_to_topic(self, document_vectors, hierarchy=False):
+
+        if hierarchy:
+            doc_top_new, doc_dist_new = self._calculate_documents_topic(self.topic_vectors_reduced,
+                                                                        document_vectors,
+                                                                        dist=True)
+            self.doc_top_reduced = np.append(self.doc_top_reduced, doc_top_new)
+            self.doc_dist_reduced = np.append(self.doc_dist_reduced, doc_dist_new)
+
+            topic_sizes_new = pd.Series(doc_top_new).value_counts()
+            for top in topic_sizes_new.index.tolist():
+                self.topic_sizes_reduced[top] += topic_sizes_new[top]
+            self.topic_sizes_reduced.sort_values(ascending=False, inplace=True)
+            self._reorder_topics(hierarchy)
+        else:
+            doc_top_new, doc_dist_new = self._calculate_documents_topic(self.topic_vectors, document_vectors, dist=True)
+            self.doc_top = np.append(self.doc_top, doc_top_new)
+            self.doc_dist = np.append(self.doc_dist, doc_dist_new)
+
+            topic_sizes_new = pd.Series(doc_top_new).value_counts()
+            for top in topic_sizes_new.index.tolist():
+                self.topic_sizes[top] += topic_sizes_new[top]
+            self.topic_sizes.sort_values(ascending=False, inplace=True)
+            self._reorder_topics(hierarchy)
+
+    def _unassign_documents_from_topic(self, doc_indexes, hierarchy=False):
+        if hierarchy:
+            doc_top_remove = self.doc_top_reduced[doc_indexes]
+            self.doc_top_reduced = np.delete(self.doc_top_reduced, doc_indexes, 0)
+            self.doc_dist_reduced = np.delete(self.doc_dist_reduced, doc_indexes, 0)
+            topic_sizes_remove = pd.Series(doc_top_remove).value_counts()
+            for top in topic_sizes_remove.index.tolist():
+                self.topic_sizes_reduced[top] -= topic_sizes_remove[top]
+            self.topic_sizes_reduced.sort_values(ascending=False, inplace=True)
+            self._reorder_topics(hierarchy)
+        else:
+            doc_top_remove = self.doc_top[doc_indexes]
+            self.doc_top = np.delete(self.doc_top, doc_indexes, 0)
+            self.doc_dist = np.delete(self.doc_dist, doc_indexes, 0)
+            topic_sizes_remove = pd.Series(doc_top_remove).value_counts()
+            for top in topic_sizes_remove.index.tolist():
+                self.topic_sizes[top] -= topic_sizes_remove[top]
+            self.topic_sizes.sort_values(ascending=False, inplace=True)
+            self._reorder_topics(hierarchy)
+
     def save(self, file):
         """
         Saves the current model to the specified file.
@@ -499,24 +561,7 @@ class Top2Vec:
         if not all((isinstance(doc, str) or isinstance(doc, np.str_)) for doc in documents):
             raise ValueError("Documents need to be a list of strings.")
 
-    def _assign_documents_to_topic(self, document_vectors, topic_vectors, topic_sizes, doc_top, doc_dist,
-                                   hierarchy=None):
-
-        doc_top_new, doc_dist_new = self._calculate_documents_topic(topic_vectors, document_vectors, dist=True)
-        doc_top = np.append(doc_top, doc_top_new)
-        doc_dist = np.append(doc_dist, doc_dist_new)
-
-        topic_sizes_new = pd.Series(doc_top_new).value_counts()
-        for top in topic_sizes_new.index.tolist():
-            topic_sizes[top] += topic_sizes_new[top]
-        topic_sizes.sort_values(ascending=False, inplace=True)
-
-        if hierarchy is None:
-            return self._reorder_topics(topic_vectors, topic_sizes, doc_top, doc_dist)
-        else:
-            return self._reorder_topics(topic_vectors, topic_sizes, doc_top, doc_dist, hierarchy)
-
-    def add_documents(self, documents, document_ids=None):
+    def add_documents(self, documents, doc_ids=None):
         """
         Update the model with new documents.
 
@@ -531,15 +576,13 @@ class Top2Vec:
         ----------
         documents: List of str
 
-        document_ids: List of str, int (Optional)
+        doc_ids: List of str, int (Optional)
 
-            Only required if document_ids were given to the original model.
+            Only required if doc_ids were given to the original model.
 
             A unique value per document that will be used for referring to documents
-            in search results. If ids are not given, the index of each document
-            in the original corpus will become the id.
-
-
+            in search results. If ids are not given to the model, the index of each
+            document in the model will become the id.
         """
 
         # add documents
@@ -549,10 +592,10 @@ class Top2Vec:
 
         # add document ids
         if self.document_ids is not None:
-            self._validate_document_ids_add_doc(documents, document_ids)
+            self._validate_document_ids_add_doc(documents, doc_ids)
             doc_ids_len = len(self.document_ids)
-            self.document_ids = np.append(self.document_ids, document_ids)
-            self.doc_id2index.update(dict(zip(document_ids, list(range(doc_ids_len, doc_ids_len + len(document_ids))))))
+            self.document_ids = np.append(self.document_ids, doc_ids)
+            self.doc_id2index.update(dict(zip(doc_ids, list(range(doc_ids_len, doc_ids_len + len(doc_ids))))))
 
         # get document vectors
         docs_processed = [self._tokenizer(doc) for doc in documents]
@@ -568,22 +611,64 @@ class Top2Vec:
         self.model.docvecs.init_sims()
 
         # update topics
-        self.topic_vectors, self.doc_top, self.doc_dist, self.topic_sizes = self._assign_documents_to_topic(
-            document_vectors,
-            self.topic_vectors,
-            self.topic_sizes,
-            self.doc_top,
-            self.doc_dist)
+        self._assign_documents_to_topic(document_vectors, hierarchy=False)
 
         if self.hierarchy is not None:
-            self.topic_vectors_reduced, self.doc_top_reduced,\
-                self.doc_dist_reduced, self.topic_sizes_reduced, self.hierarchy = self._assign_documents_to_topic(
-                    document_vectors,
-                    self.topic_vectors_reduced,
-                    self.topic_sizes_reduced,
-                    self.doc_top_reduced,
-                    self.doc_dist_reduced,
-                    self.hierarchy)
+            self._assign_documents_to_topic(document_vectors, hierarchy=True)
+
+    def delete_documents(self, doc_ids):
+        """
+        Delete documents from current model.
+
+        Warning: If document ids were not used in original model, deleting
+        documents will change the indexes and therefore doc_ids.
+
+        The documents will be deleted from the current model without changing
+        existing document, word and topic vectors. Topic sizes will be updated.
+
+        If deleting a large quantity of documents relative to the current model
+        size a new model should be trained for best results.
+
+        Parameters
+        ----------
+        doc_ids: List of str, int
+
+            A unique value per document that is used for referring to documents
+            in search results. If ids were not given to the model, the index of each
+            document in the model is the id.
+        """
+        # make sure documents exist
+        self._validate_doc_ids(doc_ids, doc_ids_neg=[])
+
+        # get document indexes from ids
+        doc_indexes = self._get_document_indexes(doc_ids)
+
+        # delete documents
+        if self.documents is not None:
+            self.documents = np.delete(self.documents, doc_indexes, 0)
+
+        # delete document ids
+        if self.document_ids is not None:
+            for doc_id in doc_ids:
+                self.doc_id2index.pop(doc_id)
+            keys = list(self.doc_id2index.keys())
+            self.document_ids = np.array(keys)
+            values = list(range(0, len(self.doc_id2index.values())))
+            self.doc_id2index = dict(zip(keys, values))
+
+        # delete document vectors
+        num_docs = len(doc_indexes)
+        self.model.docvecs.vectors_docs = np.delete(self.model.docvecs.vectors_docs, doc_indexes, 0)
+        self.model.docvecs.count -= num_docs
+        self.model.docvecs.max_rawint -= num_docs
+        self.model.docvecs.vectors_docs_norm = None
+        self.model.docvecs.init_sims()
+
+        # update topics
+        self._unassign_documents_from_topic(doc_indexes, hierarchy=False)
+
+        if self.hierarchy is not None:
+            self._unassign_documents_from_topic(doc_indexes, hierarchy=True)
 
     def get_num_topics(self, reduced=False):
         """
@@ -666,18 +751,20 @@ class Top2Vec:
         topics_words: array of shape(num_topics, 50)
             For each topic the top 50 words are returned, in order
             of semantic similarity to topic.
+            
             Example:
-                [['data', 'deep', 'learning' ... 'artificial'],          <Topic 0>
-                 ['environment', 'warming', 'climate ... 'temperature']  <Topic 1>
-                 ...]
+            [['data', 'deep', 'learning' ... 'artificial'],          <Topic 0>
+            ['environment', 'warming', 'climate ... 'temperature']  <Topic 1>
+            ...]
 
         word_scores: array of shape(num_topics, 50)
             For each topic the cosine similarity scores of the
             top 50 words to the topic are returned.
+            
             Example:
-                [[0.7132, 0.6473, 0.5700 ... 0.3455],  <Topic 0>
-                 [0.7818', 0.7671, 0.7603 ... 0.6769]  <Topic 1>
-                 ...]
+            [[0.7132, 0.6473, 0.5700 ... 0.3455],  <Topic 0>
+            [0.7818', 0.7671, 0.7603 ... 0.6769]  <Topic 1>
+            ...]
 
         topic_nums: array of int, shape(num_topics)
             The unique number of every topic will be returned.
@@ -820,14 +907,24 @@ class Top2Vec:
         doc_top = self._calculate_documents_topic(topic_vectors=top_vecs,
                                                   document_vectors=self.model.docvecs.vectors_docs,
                                                   dist=False)
-        top_vecs = np.vstack([self.model.docvecs.vectors_docs[np.where(doc_top == label)[0]].mean(axis=0)
-                              for label in set(doc_top)])
-        self.topic_vectors_reduced, self.doc_top_reduced, self.doc_dist_reduced, self.topic_sizes_reduced, \
-        self.hierarchy = self._calculate_topic_sizes(topic_vectors=top_vecs,
-                                                     hierarchy=hierarchy)
-        self.topic_words_reduced, self.topic_word_scores_reduced = self._find_topic_words_scores(
+        self.topic_vectors_reduced = np.vstack([self.model.docvecs.vectors_docs[np.where(doc_top == label)[0]]
+                                               .mean(axis=0) for label in set(doc_top)])
+
+        self.hierarchy = hierarchy
+
+        # assign documents to topic
+        self.doc_top_reduced, self.doc_dist_reduced = self._calculate_documents_topic(self.topic_vectors_reduced,
+                                                                                      self.model.docvecs.vectors_docs)
+        # find topic words and scores
+        self.topic_words_reduced, self.topic_word_scores_reduced = self._find_topic_words_and_scores(
             topic_vectors=self.topic_vectors_reduced)
 
+        # calculate topic sizes
+        self.topic_sizes_reduced = self._calculate_topic_sizes(hierarchy=True)
+
+        # re-order topics
+        self._reorder_topics(hierarchy=True)
+
         return self.hierarchy
 
     def search_documents_by_topic(self, topic_num, num_docs, return_documents=True, reduced=False):
@@ -867,8 +964,8 @@ class Top2Vec:
             document and topic vector.
 
         doc_ids: array of int, shape(num_docs)
-            Unique ids of documents. If ids were not given, the index of document
-            in the original corpus will be returned.
+            Unique ids of documents. If ids were not given to the model, the index of
+            the document in the model will be returned.
         """
 
         if reduced:
@@ -899,7 +996,7 @@ class Top2Vec:
         else:
             return doc_scores, doc_ids
 
-    def search_documents_by_keywords(self, keywords, num_docs, keywords_neg=[], return_documents=True):
+    def search_documents_by_keywords(self, keywords, num_docs, keywords_neg=None, return_documents=True):
         """
         Semantic search of documents using keywords.
 
@@ -940,9 +1037,13 @@ class Top2Vec:
             document and average of keyword vectors.
 
         doc_ids: array of int, shape(num_docs)
-            Unique ids of documents. If ids were not given, the index of document
-            in the original corpus will be returned.
+            Unique ids of documents. If ids were not given to the model, the index of
+            the document in the model will be returned.
         """
+
+        if keywords_neg is None:
+            keywords_neg = []
+
         self._validate_num_docs(num_docs)
         keywords, keywords_neg = self._validate_keywords(keywords, keywords_neg)
 
@@ -961,7 +1062,7 @@ class Top2Vec:
         else:
             return doc_scores, doc_ids
 
-    def similar_words(self, keywords, num_words, keywords_neg=[]):
+    def similar_words(self, keywords, num_words, keywords_neg=None):
         """
         Semantic similarity search of words.
 
@@ -995,6 +1096,9 @@ class Top2Vec:
             Semantic similarity of word to keywords. The cosine similarity of the
             word and average of keyword vectors.
         """
+        if keywords_neg is None:
+            keywords_neg = []
+
         keywords, keywords_neg = self._validate_keywords(keywords, keywords_neg)
         sim_words = self.model.wv.most_similar(positive=keywords,
                                                negative=keywords_neg,
@@ -1004,7 +1108,7 @@ class Top2Vec:
 
         return words, word_scores
 
-    def search_topics(self, keywords, num_topics, keywords_neg=[], reduced=False):
+    def search_topics(self, keywords, num_topics, keywords_neg=None, reduced=False):
         """
         Semantic search of topics using keywords.
 
@@ -1038,18 +1142,20 @@ class Top2Vec:
         topics_words: array of shape (num_topics, 50)
             For each topic the top 50 words are returned, in order of semantic
             similarity to topic.
+            
             Example:
-                [['data', 'deep', 'learning' ... 'artificial'],             <Topic 0>
-                 ['environment', 'warming', 'climate ... 'temperature']     <Topic 1>
-                 ...]
+            [['data', 'deep', 'learning' ... 'artificial'],             <Topic 0>
+            ['environment', 'warming', 'climate ... 'temperature']     <Topic 1>
+            ...]
 
         word_scores: array of shape (num_topics, 50)
             For each topic the cosine similarity scores of the top 50 words
             to the topic are returned.
+            
             Example:
-                [[0.7132, 0.6473, 0.5700 ... 0.3455],     <Topic 0>
-                 [0.7818', 0.7671, 0.7603 ... 0.6769]     <Topic 1>
-                 ...]
+            [[0.7132, 0.6473, 0.5700 ... 0.3455],     <Topic 0>
+            [0.7818', 0.7671, 0.7603 ... 0.6769]     <Topic 1>
+            ...]
 
         topic_scores: array of float, shape(num_topics)
             For each topic the cosine similarity to the search keywords will be
@@ -1058,6 +1164,9 @@ class Top2Vec:
         topic_nums: array of int, shape(num_topics)
             The unique number of every topic will be returned.
         """
+        if keywords_neg is None:
+            keywords_neg = []
+
         self._validate_num_topics(num_topics, reduced)
         keywords, keywords_neg = self._validate_keywords(keywords, keywords_neg)
 
@@ -1092,7 +1201,7 @@ class Top2Vec:
 
         return topic_words, word_scores, topic_scores, topic_nums
 
-    def search_documents_by_documents(self, doc_ids, num_docs, doc_ids_neg=[], return_documents=True):
+    def search_documents_by_documents(self, doc_ids, num_docs, doc_ids_neg=None, return_documents=True):
         """
         Semantic similarity search of documents.
 
@@ -1132,9 +1241,12 @@ class Top2Vec:
             document and average of keyword vectors.
 
         doc_ids: array of int, shape(num_docs)
-            Unique ids of documents. If ids were not given, the index of document
-            in the original corpus will be returned.
+            Unique ids of documents. If ids were not given to the model, the index of
+            the document in the model will be returned.
         """
+        if doc_ids_neg is None:
+            doc_ids_neg = []
+
         self._validate_num_docs(num_docs)
         self._validate_doc_ids(doc_ids, doc_ids_neg)
 
